==> jc-1.4.0.tar.gz: java/awt/dnd/DropTargetContext__24TransferableProxy.h <==
// public class java.awt.dnd.DropTargetContext$TransferableProxy

// class file dependencies
// @dep_class 2aca4df4d6b8c58b java_awt_dnd_DropTargetContext__24TransferableProxy
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_dnd_DropTargetContext__24TransferableProxy_H_
#define _JC_java_awt_dnd_DropTargetContext__24TransferableProxy_H_

// Forward structure declarations
struct _jc_java_awt_datatransfer_DataFlavor$object;
struct _jc_java_awt_datatransfer_Transferable$object;
struct _jc_java_awt_dnd_DropTargetContext$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$sub_refs	_jc_java_awt_dnd_DropTargetContext__24TransferableProxy$sub_refs;
typedef struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$sub_nonrefs	_jc_java_awt_dnd_DropTargetContext__24TransferableProxy$sub_nonrefs;
typedef struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$refs	_jc_java_awt_dnd_DropTargetContext__24TransferableProxy$refs;
typedef struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$nonrefs	_jc_java_awt_dnd_DropTargetContext__24TransferableProxy$nonrefs;
typedef struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$object	_jc_java_awt_dnd_DropTargetContext__24TransferableProxy$object;

typedef const struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$vmethods	_jc_java_awt_dnd_DropTargetContext__24TransferableProxy$vmethods;
typedef const struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$vtable	_jc_java_awt_dnd_DropTargetContext__24TransferableProxy$vtable;
typedef const struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$vtype	_jc_java_awt_dnd_DropTargetContext__24TransferableProxy$vtype;

// Constructors
extern void _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$method$_init$3708d9ded7ab75e4(_jc_env *, struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$object *, struct _jc_java_awt_dnd_DropTargetContext$object *, struct _jc_object *, jboolean);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_awt_dnd_DropTargetContext__24TransferableProxy$method$getTransferData$8a1eeb30bd3ece8d(_jc_env *, struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$object *, struct _jc_java_awt_datatransfer_DataFlavor$object *);
extern _jc_object_array *_jc_java_awt_dnd_DropTargetContext__24TransferableProxy$method$getTransferDataFlavors$14e95b4571b7e923(_jc_env *, struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$object *);
extern jboolean _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$method$isDataFlavorSupported$9e698abce62becef(_jc_env *, struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$object *, struct _jc_java_awt_datatransfer_DataFlavor$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$method_info$getTransferData$8a1eeb30bd3ece8d;
extern _jc_method _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$method_info$getTransferDataFlavors$14e95b4571b7e923;
extern _jc_method _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$method_info$isDataFlavorSupported$9e698abce62becef;

// Virtual methods structure
struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$vmethods {
	struct _jc_java_lang_Object$object	*(*getTransferData$8a1eeb30bd3ece8d)(_jc_env *, struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$object *, struct _jc_java_awt_datatransfer_DataFlavor$object *);
	_jc_object_array	*(*getTransferDataFlavors$14e95b4571b7e923)(_jc_env *, struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$object *);
	jboolean	(*isDataFlavorSupported$9e698abce62becef)(_jc_env *, struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$object *, struct _jc_java_awt_datatransfer_DataFlavor$object *);
};

// Vtable
struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_dnd_DropTargetContext__24TransferableProxy$vmethods	java_awt_dnd_DropTargetContext__24TransferableProxy;
};

// Vtype
struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$vtype {
	_jc_type			type;
	_jc_java_awt_dnd_DropTargetContext__24TransferableProxy$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$sub_refs {
	struct _jc_object	*transferable;
	struct _jc_java_awt_dnd_DropTargetContext$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$refs {
    _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$sub_refs	java_awt_dnd_DropTargetContext__24TransferableProxy;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$sub_nonrefs {
	jboolean	isLocal;
};

// Non-reference instance fields (object)
struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$sub_nonrefs	java_awt_dnd_DropTargetContext__24TransferableProxy;
};

// Object instance structure
struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$object {
	_jc_java_awt_dnd_DropTargetContext__24TransferableProxy$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_dnd_DropTargetContext__24TransferableProxy$vtype	*vtype;
	_jc_java_awt_dnd_DropTargetContext__24TransferableProxy$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$vtype _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_dnd_DropTargetContext__24TransferableProxy, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$class_object;

#endif	/* _JC_java_awt_dnd_DropTargetContext__24TransferableProxy_H_ */

==> jc-1.4.6.tar.gz: java/awt/dnd/DropTargetContext__24TransferableProxy.h <==
// public class java.awt.dnd.DropTargetContext$TransferableProxy

// class file dependencies
// @dep_class 2aca4df4d6b8c58b java_awt_dnd_DropTargetContext__24TransferableProxy
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_dnd_DropTargetContext__24TransferableProxy_H_
#define _JC_java_awt_dnd_DropTargetContext__24TransferableProxy_H_

// Forward structure declarations
struct _jc_java_awt_datatransfer_DataFlavor$object;
struct _jc_java_awt_datatransfer_Transferable$object;
struct _jc_java_awt_dnd_DropTargetContext$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$sub_refs	_jc_java_awt_dnd_DropTargetContext__24TransferableProxy$sub_refs;
typedef struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$sub_nonrefs	_jc_java_awt_dnd_DropTargetContext__24TransferableProxy$sub_nonrefs;
typedef struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$refs	_jc_java_awt_dnd_DropTargetContext__24TransferableProxy$refs;
typedef struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$nonrefs	_jc_java_awt_dnd_DropTargetContext__24TransferableProxy$nonrefs;
typedef struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$object	_jc_java_awt_dnd_DropTargetContext__24TransferableProxy$object;

typedef const struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$vmethods	_jc_java_awt_dnd_DropTargetContext__24TransferableProxy$vmethods;
typedef const struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$vtable	_jc_java_awt_dnd_DropTargetContext__24TransferableProxy$vtable;
typedef const struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$vtype	_jc_java_awt_dnd_DropTargetContext__24TransferableProxy$vtype;

// Constructors
extern void _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$method$_init$3708d9ded7ab75e4(_jc_env *, struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$object *, struct _jc_java_awt_dnd_DropTargetContext$object *, struct _jc_object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_awt_dnd_DropTargetContext__24TransferableProxy$method$getTransferData$8a1eeb30bd3ece8d(_jc_env *, struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$object *, struct _jc_java_awt_datatransfer_DataFlavor$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_java_awt_dnd_DropTargetContext__24TransferableProxy$method$getTransferDataFlavors$14e95b4571b7e923(_jc_env *, struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$method$isDataFlavorSupported$9e698abce62becef(_jc_env *, struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$object *, struct _jc_java_awt_datatransfer_DataFlavor$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$method_info$getTransferData$8a1eeb30bd3ece8d;
extern _jc_method _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$method_info$getTransferDataFlavors$14e95b4571b7e923;
extern _jc_method _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$method_info$isDataFlavorSupported$9e698abce62becef;

// Virtual methods structure
struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$vmethods {
	struct _jc_java_lang_Object$object	*(*getTransferData$8a1eeb30bd3ece8d)(_jc_env *, struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$object *, struct _jc_java_awt_datatransfer_DataFlavor$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*getTransferDataFlavors$14e95b4571b7e923)(_jc_env *, struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$object *) _JC_JCNI_ATTR;
	jboolean	(*isDataFlavorSupported$9e698abce62becef)(_jc_env *, struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$object *, struct _jc_java_awt_datatransfer_DataFlavor$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_dnd_DropTargetContext__24TransferableProxy$vmethods	java_awt_dnd_DropTargetContext__24TransferableProxy;
};

// Vtype
struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$vtype {
	_jc_type			type;
	_jc_java_awt_dnd_DropTargetContext__24TransferableProxy$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$sub_refs {
	struct _jc_object	*transferable;
	struct _jc_java_awt_dnd_DropTargetContext$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$refs {
    _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$sub_refs	java_awt_dnd_DropTargetContext__24TransferableProxy;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$sub_nonrefs {
	jboolean	isLocal;
};

// Non-reference instance fields (object)
struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$sub_nonrefs	java_awt_dnd_DropTargetContext__24TransferableProxy;
};

// Object instance structure
struct _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$object {
	_jc_java_awt_dnd_DropTargetContext__24TransferableProxy$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_dnd_DropTargetContext__24TransferableProxy$vtype	*vtype;
	_jc_java_awt_dnd_DropTargetContext__24TransferableProxy$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$vtype _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_dnd_DropTargetContext__24TransferableProxy, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_dnd_DropTargetContext__24TransferableProxy$class_object;

#endif	/* _JC_java_awt_dnd_DropTargetContext__24TransferableProxy_H_ */
